Config

Struct Config 

pub struct Config<T>(pub Arc<T>);
One section of this request’s configuration.

async fn handler(Config(db): Config<Database>) -> String {
    db.host.clone()
}

Extracting the same type twice in one handler answers the same Arc. Extracting one the layer was not given is a wiring mistake and answers 500 — see SnapshotMissing.

Tuple Fields

0: Arc<T>